@@ -19,10 +19,10 @@ class BaseAuthLegacyFileServerConnector(LegacyFileServerConnector):
     Config = LegacyFileServerConnector.Config
 
     def __init__(self, config: Config, context: Context) -> None:
-        self._server_name = config.server_name
+        self._server_name = context.project_name
         super(BaseAuthLegacyFileServerConnector, self).__init__(config, context)
 
     def _construct_headers(self) -> dict[str, str]:
         headers = super(BaseAuthLegacyFileServerConnector, self)._construct_headers()
-        headers["server_name"] = self._context.project_name
+        headers["server_name"] = self._server_name
         return headers
