@@ -20,8 +20,6 @@ class LegacyFileServerConnector:
     Context = HttpServerConnector.Context
 
     def __init__(self, config: Config, context: Context):
-        self._config = config
-        self._context = context
         self._connector = HttpServerConnector(config, context)
 
     async def get_file(self, file_id: int) -> bytes:
